#!/bin/sh
#
#apv7_install.commmand
#
#
#SETI@home and AstroPulse installer
#
#Installs the optimzed SETI@home AstroPulse and/or MultiBeam application(s) into the default
#BOINC directory on Mac OS X for SETI@home project
#
#
#V.1.0, 22.11.2008, Lars Bausch
#V.1.0b, 30.12.2009, adapted by lunatics porting team (10.5+ 64bit beta AP app)
#V.1.0c, 12.01.2010, adapted by lunatics porting team (10.4+ 32bit beta AP app)
#V.1.0d, 03.06.2011, adapted by lunatics porting team (10.5+ 64bit r237->r462 AP app)
#V.1.1, 11.06.2012, adapted by lunatics porting team (10.5+ 64bit r462->r561 AP app)
#V.1.1a, 19.06.2012, fixed permissions bug by lunatics porting team (10.5+ 64bit r561 AP app)
#V.1.2, 20.06.2013, adapted by lunatics porting team (10.7+ 64bit OpenCL AP r1874 app)
#V.1.3, 17.08.2014, adapted by lunatics porting team (10.7+ 64bit MBv7 CPU r2549 app)
#V.1.3a, 12.10.2014, adapted by lunatics porting team (10.7+ 64bit APv7 CPU SSE3 r2559 app)

APP_VERSION="ap_7.01r2559_SSE3_OSX64"
DEST="/Library/Application*Support/BOINC*Data/projects/setiathome.berkeley.edu"
SOURCE="`echo $0 | sed s/apv7_install.command// `"

clear
echo "                   SETI@home optimized app installer"
echo ""
echo ""
echo "This script will install an optimized AstroPulse v7 $APP_VERSION on your system."
echo ""
echo "Please stop the BOINC client before you install the optimized Astropulse application !"
echo ""
echo "Did you stop the BOINC client already (y) ? \c"
read CONT

if  [ "$CONT" != "y" ]; then
  echo "Aborting installation..."
  echo ""
  exit 1
fi

echo ""
echo "The installation uses sudo to install the files with correct permissions set."
echo "Eventually you will be prompted for a password now. This password is your "
echo "own password on your system with your actual account !"
echo ""
sudo ls $DEST > /dev/null 2>&1

echo ""
echo "Copying files to the BOINC directory..."
sudo mkdir  $DEST 2> /dev/null
cd $SOURCE
sudo cp $SOURCE/app_info.xml $DEST
if  [ "$?" = "0" ]; then
  echo "Copied "app_info.xml" successfull"
else
  echo "Copying "app_info.xml" not successfull"
  exit 1
fi

sudo cp $SOURCE/$APP_VERSION $DEST
if  [ "$?" = "0" ]; then
  echo "Copied $APP_VERSION successful"
else
  echo "Copying $APP_VERSION NOT successful"
  exit 1
fi

echo ""
echo "Setting permissions of the SETI@home projects directory file hirarchy …"

#First make sure read write and executable permissions for executable are set like BOINC does
sudo chmod u+r+w+x,g+r+w+x,o+r-w-x $DEST/$APP_VERSION
#Second make sure write- and executable-rights are set for the group on directory
sudo chmod u+r+w+x,g+r+w+x,o+r-w+x $DEST
#Third make sure owner and group are set to BOINCs defaults
sudo chown -R boinc_master:boinc_project $DEST
if  [ "$?" = "0" ]; then
  echo "Set permissions successful"
 else
  echo "Set permissions was NOT successful! \n"
  echo "Please reuse BOINC installer for your version of BOINC to rearrange permissions.\n"
  exit 1
fi

echo ""
echo "Optimzed AstroPulse v7 application installation script has finished."
echo " Please restart your BOINC client now ! "
echo ""

exit 0
